==> js_2020_03_27.tar.gz: js/tree/numericComma.js <==
/**
 * It is not uncommon for non-English speaking countries to use a comma for a
 * decimal place. This sorting plug-in shows how that can be taken account of in
 * sorting by adding the type `numeric-comma` to DataTables. A type detection 
 * plug-in for this sorting method is provided below.
 * 
 * Please note that the 'Formatted numbers' type detection and sorting plug-ins
 * offer greater flexibility that this plug-in and should be used in preference
 * to this method.
 *
 *  @name Commas for decimal place
 *  @summary Sort numbers correctly which use a comma as the decimal place.
 *  @deprecated
 *  @author [Allan Jardine](http://sprymedia.co.uk)
 *
 *  @example
 *    $('#example').dataTable( {
 *       columnDefs: [
 *         { type: 'numeric-comma', targets: 0 }
 *       ]
 *    } );
 */


	function isoDate( s){
var from = s.split(".");
var f = new Date(from[2], from[1] - 1, from[0]);
return f;
	}
	





jQuery.extend( jQuery.fn.dataTableExt.oSort, {
    
    
    'sss-desc' : function(x,y) {
    console.log("TEST2");
    var CDateX = isoDate(x);
    var CDateY = isoDate(y);
    
    return CDateY<CDateX;
    },
    
    'sss-asc':function(x,y) {
    console.log("TEST "+typeof(x));
    var CDateX = isoDate(x);
    var CDateY = isoDate(y);
    
    return CDateX<CDateY;
    },
    
    
	'numericcomma00-pre': function ( a ) {
        //console.log('numeric-comma-pre '+a);
		//var x = (a == "-") ? 0 : a.replace( /,/, "." );
		//return parseFloat( x );
        var x = parseInt( a );
        console.log("-x="+x);
        return x;
	},

	'numericcomma-asc': function ( a, b ) {
        console.log("numeric-comma-asc "+a+" "+b);
		//return ((a < b) ? -1 : ((a > b) ? 1 : 0));
        return 1;
	},

	'numericcomma-desc': function ( a, b ) {
        console.log('numeric-comma-desc');
		//return ((a < b) ? 1 : ((a > b) ? -1 : 0));
        return 1;
	}
} );

==> js_2020_04_14.tar.gz: js/tree/numericComma.js <==
/**
 * It is not uncommon for non-English speaking countries to use a comma for a
 * decimal place. This sorting plug-in shows how that can be taken account of in
 * sorting by adding the type `numeric-comma` to DataTables. A type detection 
 * plug-in for this sorting method is provided below.
 * 
 * Please note that the 'Formatted numbers' type detection and sorting plug-ins
 * offer greater flexibility that this plug-in and should be used in preference
 * to this method.
 *
 *  @name Commas for decimal place
 *  @summary Sort numbers correctly which use a comma as the decimal place.
 *  @deprecated
 *  @author [Allan Jardine](http://sprymedia.co.uk)
 *
 *  @example
 *    $('#example').dataTable( {
 *       columnDefs: [
 *         { type: 'numeric-comma', targets: 0 }
 *       ]
 *    } );
 */


	function isoDate( s){
    
      
        
if('string'!==typeof(s))
    return false;
   
var from = s.split(".");
var f = new Date(from[2], from[1] - 1, from[0]);
return f;
	}
	





jQuery.extend( jQuery.fn.dataTableExt.oSort, {
    
    
    'sss2-desc' : function(x,y) {
    console.log("js TEST2");
    var CDateX = isoDate(x);
    var CDateY = isoDate(y);
    
    return CDateY<CDateX;
    },
    
    'sss2-asc':function(x,y) {
    console.log("js TEST "+typeof(x));
    var CDateX = isoDate(x);
    var CDateY = isoDate(y);
    
     console.log(CDateX+" js TEST "+CDateY);
     
    return CDateX<CDateY;
    },
    
    
	'numericcomma00-pre': function ( a ) {
        //console.log('numeric-comma-pre '+a);
		//var x = (a == "-") ? 0 : a.replace( /,/, "." );
		//return parseFloat( x );
        var x = parseInt( a );
        console.log("-x="+x);
        return x;
	},

	'numericcomma-asc': function ( a, b ) {
        console.log("numeric-comma-asc "+a+" "+b);
		//return ((a < b) ? -1 : ((a > b) ? 1 : 0));
        return 1;
	},

	'numericcomma-desc': function ( a, b ) {
        console.log('numeric-comma-desc');
		//return ((a < b) ? 1 : ((a > b) ? -1 : 0));
        return 1;
	}
} );
